.. toctree::
   :maxdepth: 2
   :hidden:

   installation
   quickstart
   modules
   project

.. include:: ../../README.rst
   :start-after: inclusion-marker-LIGHTSHOW-begin
   :end-before: inclusion-marker-LIGHTSHOW-end

Overview
========

.. include:: ../../README.rst
   :start-after: inclusion-marker-LIGHTSHOW-overview-begin
   :end-before: inclusion-marker-LIGHTSHOW-overview-end


